<?php

namespace Drupal\recurly_aegir\Provisioners;

/**
 * Fetches the list of profiles via Aegir's Web service API.
 */
class RecurlyAegirProfileListProvisioner extends RecurlyAegirProvisioner {

  /**
   * The human-readable task type used by this provisioner.
   */
  const TASK_TYPE = 'List profiles';

  /**
   * {@inheritdoc}
   */
  public static function getTaskType() {
    return self::TASK_TYPE;
  }

  /**
   * {@inheritdoc}
   *
   * Returns the list of allowed profiles.
   */
  public function provision() {
    $this->sendRequestAndReceiveResponse('profile.json', []);
    return $this;
  }

  /**
   * {@inheritdoc}
   *
   * @return array
   *   The list of query string parameters
   */
  protected function getQueryParametersToSend() {
    return ['machine_names' => 1];
  }

  /**
   * Fetch the list of profiles and return it.
   *
   * @param bool $cacheable
   *   Boolean indicating if the results are cacheable.
   *
   * @return array
   *   The list of profiles.
   */
  public static function getProfileList($cacheable) {
    $provisioner = new static();
    $profiles = $provisioner->provision()->getResponse();
    return $profiles;
  }

}
