<?php

namespace Drupal\recurly_aegir\Provisioners;

use Drupal\recurly_aegir\Exceptions\RecurlyAegirTaskCreationFailedException;

/**
 * Base class for provisioning new sites via Aegir's Web service API.
 *
 * @todo Make this class a plugin manager and make the subclasses plugins.
 */
abstract class RecurlyAegirSiteProvisioner extends RecurlyAegirProvisioner {

  /**
   * The virtual hostname of the site to provision.
   *
   * @var string
   */
  protected $hostname;

  /**
   * Class Constructor.
   *
   * @param string $hostname
   *   The virtual hostname of the site to provision.
   */
  public function __construct($hostname) {
    if (empty($hostname)) {
      throw new \Exception('Site provisioners must be provided with a hostname on construction.');
    }

    $this->hostname = $hostname;
  }

  /**
   * Returns the Aegir task ID returned after provisioning a site.
   *
   * @return int
   *   The task ID.
   *
   * @throws RecurlyAegirTaskCreationFailedException
   *   If there is no task ID because the service call failed.
   *
   * @see $this->provision()
   */
  public function getTaskId() {
    if (empty($this->response['nid'])) {
      throw new RecurlyAegirTaskCreationFailedException(sprintf(
        'Task creation failed for %s via %s with template %s.',
        $this->hostname,
        (new \ReflectionClass(get_class($this)))->getShortName(),
        property_exists($this, 'template') ? $this->template : 'NO TEMPLATE'
      ));
    }
    return $this->response['nid'];
  }

  /**
   * Returns the target hostname associated with this provisioner.
   */
  public function getHostname() {
    return $this->hostname;
  }

}
